.. highlight:: rst

PyQchem
=======

A python wrapper for Q-Chem software (https://www.q-chem.com).

.. toctree::
    :maxdepth: 1
    :caption: Contents

    introduction
    installation
    starting
    advanced
    symmetry
    errors
    tutorial
    api
    troubleshooting

PyQchem is being developed by Abel Carreras within David Casanova's group
at Donostia International Physics Center (DIPC), Euskadi, Spain.

